@@ -1,6 +1,5 @@
 extern crate shared_memory;
 use shared_memory::*;
-use std::ffi::OsStr;
 
 #[macro_use]
 extern crate enum_primitive;
@@ -25,7 +24,7 @@ fn main() -> Result<()> {
 
     //Create a custom configuration for our mapping
     let mut my_conf = SharedMemConf::new()
-        .set_link_path(&OsStr::new("shared_mem.link"))
+        .set_link_path("shared_mem.link")
         .set_os_path("test_mapping")
         .set_size(4096);
 
